@@ -1,5 +1,6 @@
+use std::borrow::Cow;
 use std::collections::HashSet;
-use once_cell::sync::Lazy;
+use std::sync::OnceLock;
 
 use regex::Regex;
 
@@ -27,7 +28,7 @@ impl WriteSource for pr::Expr {
         let mut r = String::new();
 
         if let Some(alias) = &self.alias {
-            r += opt.consume(alias)?;
+            r += opt.consume(&write_ident_part(alias))?;
             r += opt.consume(" = ")?;
             opt.unbound_expr = false;
         }
@@ -90,7 +91,7 @@ impl WriteSource for pr::ExprKind {
         use pr::ExprKind::*;
 
         match &self {
-            Ident(ident) => Some(write_ident_part(ident)),
+            Ident(ident) => Some(write_ident_part(ident).into_owned()),
             Indirection { base, field } => {
                 let mut r = base.write(opt.clone())?;
                 opt.consume_width(r.len() as u16)?;
@@ -360,23 +361,29 @@ impl WriteSource for pr::Ident {
     }
 }
 
-pub static KEYWORDS: Lazy<HashSet<&str>> = Lazy::new(|| {
-    HashSet::from_iter([
-        "let", "into", "case", "prql", "type", "module", "internal", "func",
-    ])
-});
+fn keywords() -> &'static HashSet<&'static str> {
+    static KEYWORDS: OnceLock<HashSet<&'static str>> = OnceLock::new();
+    KEYWORDS.get_or_init(|| {
+        HashSet::from_iter([
+            "let", "into", "case", "prql", "type", "module", "internal", "func",
+        ])
+    })
+}
 
-pub static VALID_PRQL_IDENT: Lazy<Regex> = Lazy::new(|| {
-    // Pomsky expression (regex is to Pomsky what SQL is to PRQL):
-    // ^ ('*' | [ascii_alpha '_$'] [ascii_alpha ascii_digit '_$']* ) $
-    Regex::new(r"^(?:\*|[a-zA-Z_$][a-zA-Z0-9_$]*)$").unwrap()
-});
+fn valid_prql_ident() -> &'static Regex {
+    static VALID_PRQL_IDENT: OnceLock<Regex> = OnceLock::new();
+    VALID_PRQL_IDENT.get_or_init(|| {
+        // Pomsky expression (regex is to Pomsky what SQL is to PRQL):
+        // ^ ('*' | [ascii_alpha '_$'] [ascii_alpha ascii_digit '_$']* ) $
+        Regex::new(r"^(?:\*|[a-zA-Z_$][a-zA-Z0-9_$]*)$").unwrap()
+    })
+}
 
-pub fn write_ident_part(s: &str) -> String {
-    if VALID_PRQL_IDENT.is_match(s) && !KEYWORDS.contains(s) {
-        s.to_string()
+pub fn write_ident_part(s: &str) -> Cow<str> {
+    if valid_prql_ident().is_match(s) && !keywords().contains(s) {
+        s.into()
     } else {
-        format!("`{}`", s)
+        format!("`{}`", s).into()
     }
 }
 
@@ -576,14 +583,14 @@ mod test {
             exprs: vec![short.clone(), long.clone(), long, short.clone()],
         }));
         // colons are a workaround to avoid trimming
-        assert_snapshot!(pipeline.write(opt.clone()).unwrap(), @r###"
+        assert_snapshot!(pipeline.write(opt.clone()).unwrap(), @r"
         (
             short
             some_really_long_and_really_long_name
             some_really_long_and_really_long_name
             short
           )
-        "###);
+        ");
 
         // sometimes, there is just not enough space
         opt.rem_width = 4;
@@ -638,6 +645,15 @@ aggregate average_country_salary = (
         );
     }
 
+    #[test]
+    fn test_alias() {
+        assert_is_formatted(
+            r#"
+from artists
+select {`customer name` = foo, x = bar.baz}"#,
+        );
+    }
+
     #[test]
     fn test_assign() {
         assert_is_formatted(
