@@ -1,27 +1,28 @@
+use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use prqlc_ast::expr::generic::Range;
+use prqlc_parser::generic;
 
-#[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq)]
+#[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq, JsonSchema)]
 pub struct ColumnSort<T> {
     pub direction: SortDirection,
     pub column: T,
 }
 
-#[derive(Debug, Clone, Serialize, Default, Deserialize, PartialEq, Eq)]
+#[derive(Debug, Clone, Serialize, Default, Deserialize, PartialEq, Eq, JsonSchema)]
 pub enum SortDirection {
     #[default]
     Asc,
     Desc,
 }
 
-#[derive(Debug, PartialEq, Eq, Clone, Serialize, Deserialize)]
+#[derive(Debug, PartialEq, Eq, Clone, Serialize, Deserialize, JsonSchema)]
 pub struct WindowFrame<T> {
     pub kind: WindowKind,
-    pub range: prqlc_ast::expr::generic::Range<T>,
+    pub range: generic::Range<T>,
 }
 
-#[derive(Debug, PartialEq, Eq, Clone, Serialize, Deserialize)]
+#[derive(Debug, PartialEq, Eq, Clone, Serialize, Deserialize, JsonSchema)]
 pub enum WindowKind {
     Rows,
     Range,
@@ -33,7 +34,7 @@ impl<T> WindowFrame<T> {
             self,
             WindowFrame {
                 kind: WindowKind::Rows,
-                range: Range {
+                range: generic::Range {
                     start: None,
                     end: None
                 }
@@ -46,7 +47,7 @@ impl<T> Default for WindowFrame<T> {
     fn default() -> Self {
         Self {
             kind: WindowKind::Rows,
-            range: Range::unbounded(),
+            range: generic::Range::unbounded(),
         }
     }
 }
