@@ -1,9 +1,9 @@
 //! Intermediate Representations of Abstract Syntax Tree
 //!
+pub use prqlc_parser::span::Span;
+
 pub mod constant;
 pub mod decl;
 pub mod generic;
 pub mod pl;
 pub mod rq;
-
-pub use prqlc_ast::Span;
