@@ -1,14 +1,19 @@
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
+// Licensed to the Apache Software Foundation (ASF) under one
+// or more contributor license agreements.  See the NOTICE file
+// distributed with this work for additional information
+// regarding copyright ownership.  The ASF licenses this file
+// to you under the Apache License, Version 2.0 (the
+// "License"); you may not use this file except in compliance
+// with the License.  You may obtain a copy of the License at
 //
-// http://www.apache.org/licenses/LICENSE-2.0
+//   http://www.apache.org/licenses/LICENSE-2.0
 //
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
+// Unless required by applicable law or agreed to in writing,
+// software distributed under the License is distributed on an
+// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied.  See the License for the
+// specific language governing permissions and limitations
+// under the License.
 
 //! This module defines
 //! 1) a list of constants for every keyword
@@ -20,7 +25,7 @@
 //!     As a matter of fact, most of these keywords are not used at all
 //!     and could be removed.
 //! 3) a `RESERVED_FOR_TABLE_ALIAS` array with keywords reserved in a
-//! "table alias" context.
+//!     "table alias" context.
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -77,6 +82,7 @@ define_keywords!(
     AFTER,
     AGAINST,
     AGGREGATION,
+    ALIAS,
     ALL,
     ALLOCATE,
     ALTER,
@@ -107,6 +113,7 @@ define_keywords!(
     AVRO,
     BACKWARD,
     BASE64,
+    BEFORE,
     BEGIN,
     BEGIN_FRAME,
     BEGIN_PARTITION,
@@ -123,6 +130,7 @@ define_keywords!(
     BOTH,
     BROWSE,
     BTREE,
+    BUCKETS,
     BY,
     BYPASSRLS,
     BYTEA,
@@ -135,6 +143,7 @@ define_keywords!(
     CASCADED,
     CASE,
     CAST,
+    CATALOG,
     CEIL,
     CEILING,
     CENTURY,
@@ -149,10 +158,12 @@ define_keywords!(
     CHARSET,
     CHAR_LENGTH,
     CHECK,
+    CLEAR,
     CLOB,
     CLONE,
     CLOSE,
     CLUSTER,
+    CLUSTERED,
     COALESCE,
     COLLATE,
     COLLATION,
@@ -160,6 +171,7 @@ define_keywords!(
     COLLECTION,
     COLUMN,
     COLUMNS,
+    COLUMNSTORE,
     COMMENT,
     COMMIT,
     COMMITTED,
@@ -172,6 +184,7 @@ define_keywords!(
     CONNECTION,
     CONSTRAINT,
     CONTAINS,
+    CONTINUE,
     CONVERT,
     COPY,
     COPY_OPTIONS,
@@ -204,6 +217,7 @@ define_keywords!(
     CYCLE,
     DATA,
     DATABASE,
+    DATABASES,
     DATA_RETENTION_TIME_IN_DAYS,
     DATE,
     DATE32,
@@ -217,6 +231,7 @@ define_keywords!(
     DECADE,
     DECIMAL,
     DECLARE,
+    DEDUPLICATE,
     DEFAULT,
     DEFAULT_DDL_COLLATION,
     DEFERRABLE,
@@ -267,6 +282,7 @@ define_keywords!(
     ENFORCED,
     ENGINE,
     ENUM,
+    EPHEMERAL,
     EPOCH,
     EQUALS,
     ERROR,
@@ -297,7 +313,9 @@ define_keywords!(
     FILE,
     FILES,
     FILE_FORMAT,
+    FILL,
     FILTER,
+    FINAL,
     FIRST,
     FIRST_VALUE,
     FIXEDSTRING,
@@ -344,6 +362,7 @@ define_keywords!(
     HASH,
     HAVING,
     HEADER,
+    HEAP,
     HIGH_PRIORITY,
     HISTORY,
     HIVEVAR,
@@ -351,6 +370,7 @@ define_keywords!(
     HOSTS,
     HOUR,
     HOURS,
+    ID,
     IDENTITY,
     IF,
     IGNORE,
@@ -372,6 +392,7 @@ define_keywords!(
     INSENSITIVE,
     INSERT,
     INSTALL,
+    INSTEAD,
     INT,
     INT128,
     INT16,
@@ -382,6 +403,7 @@ define_keywords!(
     INT64,
     INT8,
     INTEGER,
+    INTERPOLATE,
     INTERSECT,
     INTERSECTION,
     INTERVAL,
@@ -416,6 +438,7 @@ define_keywords!(
     LIKE_REGEX,
     LIMIT,
     LINES,
+    LISTEN,
     LN,
     LOAD,
     LOCAL,
@@ -432,11 +455,13 @@ define_keywords!(
     MACRO,
     MANAGEDLOCATION,
     MAP,
+    MASKING,
     MATCH,
     MATCHED,
     MATCHES,
     MATCH_CONDITION,
     MATCH_RECOGNIZE,
+    MATERIALIZE,
     MATERIALIZED,
     MAX,
     MAXVALUE,
@@ -482,12 +507,14 @@ define_keywords!(
     NOINHERIT,
     NOLOGIN,
     NONE,
+    NOORDER,
     NOREPLICATION,
     NORMALIZE,
     NOSCAN,
     NOSUPERUSER,
     NOT,
     NOTHING,
+    NOTIFY,
     NOWAIT,
     NO_WRITE_TO_BINLOG,
     NTH_VALUE,
@@ -518,6 +545,7 @@ define_keywords!(
     OR,
     ORC,
     ORDER,
+    ORDINALITY,
     OUT,
     OUTER,
     OUTPUTFORMAT,
@@ -531,6 +559,7 @@ define_keywords!(
     PARALLEL,
     PARAMETER,
     PARQUET,
+    PART,
     PARTITION,
     PARTITIONED,
     PARTITIONS,
@@ -544,9 +573,11 @@ define_keywords!(
     PERCENTILE_DISC,
     PERCENT_RANK,
     PERIOD,
+    PERMISSIVE,
     PERSISTENT,
     PIVOT,
     PLACING,
+    PLAN,
     PLANS,
     POLICY,
     PORTION,
@@ -565,6 +596,7 @@ define_keywords!(
     PRIVILEGES,
     PROCEDURE,
     PROGRAM,
+    PROJECTION,
     PURGE,
     QUALIFY,
     QUARTER,
@@ -609,6 +641,7 @@ define_keywords!(
     RESTART,
     RESTRICT,
     RESTRICTED,
+    RESTRICTIVE,
     RESULT,
     RESULTSET,
     RETAIN,
@@ -632,6 +665,7 @@ define_keywords!(
     SAFE_CAST,
     SAVEPOINT,
     SCHEMA,
+    SCHEMAS,
     SCOPE,
     SCROLL,
     SEARCH,
@@ -662,6 +696,7 @@ define_keywords!(
     SNAPSHOT,
     SOME,
     SORT,
+    SORTED,
     SOURCE,
     SPATIAL,
     SPECIFIC,
@@ -674,6 +709,7 @@ define_keywords!(
     STABLE,
     STAGE,
     START,
+    STATEMENT,
     STATIC,
     STATISTICS,
     STATUS,
@@ -681,6 +717,7 @@ define_keywords!(
     STDDEV_SAMP,
     STDIN,
     STDOUT,
+    STEP,
     STORAGE_INTEGRATION,
     STORED,
     STRICT,
@@ -738,6 +775,7 @@ define_keywords!(
     TRUE,
     TRUNCATE,
     TRY_CAST,
+    TRY_CONVERT,
     TUPLE,
     TYPE,
     UESCAPE,
@@ -750,6 +788,7 @@ define_keywords!(
     UNBOUNDED,
     UNCACHE,
     UNCOMMITTED,
+    UNFREEZE,
     UNION,
     UNIQUE,
     UNKNOWN,
@@ -787,8 +826,10 @@ define_keywords!(
     VERSION,
     VERSIONING,
     VIEW,
+    VIEWS,
     VIRTUAL,
     VOLATILE,
+    WAREHOUSE,
     WEEK,
     WHEN,
     WHENEVER,
@@ -844,6 +885,7 @@ pub const RESERVED_FOR_TABLE_ALIAS: &[Keyword] = &[
     Keyword::USING,
     Keyword::CLUSTER,
     Keyword::DISTRIBUTE,
+    Keyword::GLOBAL,
     // for MSSQL-specific OUTER APPLY (seems reserved in most dialects)
     Keyword::OUTER,
     Keyword::SET,
