@@ -27,9 +27,8 @@ fn test_prepare_stream() {
     let input = "from artists | filter name == 'John'";
     let tokens = lex_source(input).unwrap();
 
-    let mut stream = prepare_stream(tokens.0.into_iter(), input, 0);
-    assert_yaml_snapshot!(stream.fetch_tokens().collect::<Vec<(TokenKind, Span)>>(), @r###"
-    ---
+    let mut stream = prepare_stream(tokens.0, 0);
+    assert_yaml_snapshot!(stream.fetch_tokens().collect::<Vec<(TokenKind, Span)>>(), @r#"
     - - Start
       - "0:0-0"
     - - Ident: from
@@ -47,13 +46,12 @@ fn test_prepare_stream() {
     - - Literal:
           String: John
       - "0:30-36"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_ranges() {
-    assert_yaml_snapshot!(parse_expr(r#"3..5"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"3..5"#).unwrap(), @r#"
     Range:
       start:
         Literal:
@@ -64,10 +62,9 @@ fn test_ranges() {
           Integer: 5
         span: "0:3-4"
     span: "0:0-4"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"-2..-5"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"-2..-5"#).unwrap(), @r#"
     Range:
       start:
         Unary:
@@ -86,10 +83,9 @@ fn test_ranges() {
             span: "0:5-6"
         span: "0:4-6"
     span: "0:0-6"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"(-2..(-5 | abs))"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"(-2..(-5 | abs))"#).unwrap(), @r#"
     Range:
       start:
         Unary:
@@ -113,10 +109,9 @@ fn test_ranges() {
               span: "0:11-14"
         span: "0:6-14"
     span: "0:0-16"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"(2 + 5)..'a'"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"(2 + 5)..'a'"#).unwrap(), @r#"
     Range:
       start:
         Binary:
@@ -135,10 +130,9 @@ fn test_ranges() {
           String: a
         span: "0:9-12"
     span: "0:0-12"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"1.6..rel.col"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"1.6..rel.col"#).unwrap(), @r#"
     Range:
       start:
         Literal:
@@ -153,10 +147,9 @@ fn test_ranges() {
             Name: col
         span: "0:8-12"
     span: "0:0-12"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"6.."#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"6.."#).unwrap(), @r#"
     Range:
       start:
         Literal:
@@ -164,9 +157,8 @@ fn test_ranges() {
         span: "0:0-1"
       end: ~
     span: "0:0-3"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"..7"#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"..7"#).unwrap(), @r#"
     Range:
       start: ~
       end:
@@ -174,18 +166,16 @@ fn test_ranges() {
           Integer: 7
         span: "0:2-3"
     span: "0:0-3"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#".."#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#".."#).unwrap(), @r#"
     Range:
       start: ~
       end: ~
     span: "0:0-2"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"@2020-01-01..@2021-01-01"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"@2020-01-01..@2021-01-01"#).unwrap(), @r#"
     Range:
       start:
         Literal:
@@ -196,13 +186,12 @@ fn test_ranges() {
           Date: 2021-01-01
         span: "0:13-24"
     span: "0:0-24"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_basic_exprs() {
-    assert_yaml_snapshot!(parse_expr(r#"country == "USA""#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"country == "USA""#).unwrap(), @r#"
     Binary:
       left:
         Ident: country
@@ -213,9 +202,8 @@ fn test_basic_exprs() {
           String: USA
         span: "0:11-16"
     span: "0:0-16"
-    "###);
-    assert_yaml_snapshot!(parse_expr("select {a, b, c}").unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr("select {a, b, c}").unwrap(), @r#"
     FuncCall:
       name:
         Ident: select
@@ -230,13 +218,12 @@ fn test_basic_exprs() {
               span: "0:14-15"
           span: "0:7-16"
     span: "0:0-16"
-    "###);
+    "#);
     assert_yaml_snapshot!(parse_expr(
             "group {title, country} (
                 aggregate {sum salary}
             )"
-        ).unwrap(), @r###"
-    ---
+        ).unwrap(), @r#"
     FuncCall:
       name:
         Ident: group
@@ -265,11 +252,10 @@ fn test_basic_exprs() {
                 span: "0:51-63"
           span: "0:41-63"
     span: "0:0-77"
-    "###);
+    "#);
     assert_yaml_snapshot!(parse_expr(
             r#"    filter country == "USA""#
-        ).unwrap(), @r###"
-    ---
+        ).unwrap(), @r#"
     FuncCall:
       name:
         Ident: filter
@@ -286,9 +272,8 @@ fn test_basic_exprs() {
               span: "0:22-27"
           span: "0:11-27"
     span: "0:4-27"
-    "###);
-    assert_yaml_snapshot!(parse_expr("{a, b, c,}").unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr("{a, b, c,}").unwrap(), @r#"
     Tuple:
       - Ident: a
         span: "0:1-2"
@@ -297,14 +282,13 @@ fn test_basic_exprs() {
       - Ident: c
         span: "0:7-8"
     span: "0:0-10"
-    "###);
+    "#);
     assert_yaml_snapshot!(parse_expr(
             r#"{
   gross_salary = salary + payroll_tax,
   gross_cost   = gross_salary + benefits_cost
 }"#
-        ).unwrap(), @r###"
-    ---
+        ).unwrap(), @r#"
     Tuple:
       - Binary:
           left:
@@ -327,12 +311,11 @@ fn test_basic_exprs() {
         span: "0:58-86"
         alias: gross_cost
     span: "0:0-88"
-    "###);
+    "#);
 
     assert_yaml_snapshot!(parse_expr(
             "join side:left country (id==employee_id)"
-        ).unwrap(), @r###"
-    ---
+        ).unwrap(), @r#"
     FuncCall:
       name:
         Ident: join
@@ -354,9 +337,8 @@ fn test_basic_exprs() {
           Ident: left
           span: "0:10-14"
     span: "0:0-40"
-    "###);
-    assert_yaml_snapshot!(parse_expr("1  + 2").unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr("1  + 2").unwrap(), @r#"
     Binary:
       left:
         Literal:
@@ -368,53 +350,48 @@ fn test_basic_exprs() {
           Integer: 2
         span: "0:5-6"
     span: "0:0-6"
-    "###)
+    "#)
 }
 
 #[test]
 fn test_string() {
     let double_quoted_ast = parse_expr(r#"" U S A ""#).unwrap();
-    assert_yaml_snapshot!(double_quoted_ast, @r###"
-    ---
+    assert_yaml_snapshot!(double_quoted_ast, @r#"
     Literal:
       String: " U S A "
     span: "0:0-9"
-    "###);
+    "#);
 
     let single_quoted_ast = parse_expr(r#"' U S A '"#).unwrap();
     assert_eq!(single_quoted_ast, double_quoted_ast);
 
     // Single quotes within double quotes should produce a string containing
     // the single quotes (and vice versa).
-    assert_yaml_snapshot!(parse_expr(r#""' U S A '""#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#""' U S A '""#).unwrap(), @r#"
     Literal:
       String: "' U S A '"
     span: "0:0-11"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"'" U S A "'"#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"'" U S A "'"#).unwrap(), @r#"
     Literal:
       String: "\" U S A \""
     span: "0:0-11"
-    "###);
+    "#);
 
     parse_expr(r#"" U S A"#).unwrap_err();
     parse_expr(r#"" U S A '"#).unwrap_err();
 
-    assert_yaml_snapshot!(parse_expr(r#"" \nU S A ""#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"" \nU S A ""#).unwrap(), @r#"
     Literal:
       String: " \nU S A "
     span: "0:0-11"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"r" \nU S A ""#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"r" \nU S A ""#).unwrap(), @r#"
     Literal:
-      String: " \\nU S A "
+      RawString: " \\nU S A "
     span: "0:0-12"
-    "###);
+    "#);
 
     let multi_double = parse_expr(
         r#""""
@@ -425,12 +402,11 @@ Canada
 """"#,
     )
     .unwrap();
-    assert_yaml_snapshot!(multi_double, @r###"
-    ---
+    assert_yaml_snapshot!(multi_double, @r#"
     Literal:
       String: "\n''\nCanada\n\"\n\n"
     span: "0:0-20"
-    "###);
+    "#);
 
     let multi_single = parse_expr(
         r#"'''
@@ -441,27 +417,24 @@ Canada
 '''"#,
     )
     .unwrap();
-    assert_yaml_snapshot!(multi_single, @r###"
-    ---
+    assert_yaml_snapshot!(multi_single, @r#"
     Literal:
       String: "\nCanada\n\"\n\"\"\"\n\n"
     span: "0:0-21"
-    "###);
+    "#);
 
     assert_yaml_snapshot!(
           parse_expr("''").unwrap(),
-          @r###"
-    ---
+          @r#"
     Literal:
       String: ""
     span: "0:0-2"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_s_string() {
-    assert_yaml_snapshot!(parse_expr(r#"s"SUM({col})""#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"s"SUM({col})""#).unwrap(), @r#"
     SString:
       - String: SUM(
       - Expr:
@@ -471,9 +444,8 @@ fn test_s_string() {
           format: ~
       - String: )
     span: "0:0-13"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"s"SUM({rel.`Col name`})""#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"s"SUM({rel.`Col name`})""#).unwrap(), @r#"
     SString:
       - String: SUM(
       - Expr:
@@ -488,30 +460,27 @@ fn test_s_string() {
           format: ~
       - String: )
     span: "0:0-24"
-    "###)
+    "#)
 }
 
 #[test]
 fn test_s_string_braces() {
-    assert_yaml_snapshot!(parse_expr(r#"s"{{?crystal_var}}""#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"s"{{?crystal_var}}""#).unwrap(), @r#"
     SString:
       - String: "{?crystal_var}"
     span: "0:0-19"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"s"foo{{bar""#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"s"foo{{bar""#).unwrap(), @r#"
     SString:
       - String: "foo{bar"
     span: "0:0-11"
-    "###);
+    "#);
     parse_expr(r#"s"foo{{bar}""#).unwrap_err();
 }
 
 #[test]
 fn test_tuple() {
-    assert_yaml_snapshot!(parse_expr(r#"{1 + 1, 2}"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"{1 + 1, 2}"#).unwrap(), @r#"
     Tuple:
       - Binary:
           left:
@@ -528,9 +497,8 @@ fn test_tuple() {
           Integer: 2
         span: "0:8-9"
     span: "0:0-10"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"{1 + (f 1), 2}"#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"{1 + (f 1), 2}"#).unwrap(), @r#"
     Tuple:
       - Binary:
           left:
@@ -553,14 +521,13 @@ fn test_tuple() {
           Integer: 2
         span: "0:12-13"
     span: "0:0-14"
-    "###);
+    "#);
     // Line breaks
     assert_yaml_snapshot!(parse_expr(
             r#"{1,
 
                 2}"#
-        ).unwrap(), @r###"
-    ---
+        ).unwrap(), @r#"
     Tuple:
       - Literal:
           Integer: 1
@@ -569,12 +536,11 @@ fn test_tuple() {
           Integer: 2
         span: "0:21-22"
     span: "0:0-23"
-    "###);
+    "#);
     // Function call in a tuple
     let ab = parse_expr(r#"{a b}"#).unwrap();
     let a_comma_b = parse_expr(r#"{a, b}"#).unwrap();
-    assert_yaml_snapshot!(ab, @r###"
-    ---
+    assert_yaml_snapshot!(ab, @r#"
     Tuple:
       - FuncCall:
           name:
@@ -585,20 +551,18 @@ fn test_tuple() {
               span: "0:3-4"
         span: "0:1-4"
     span: "0:0-5"
-    "###);
-    assert_yaml_snapshot!(a_comma_b, @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(a_comma_b, @r#"
     Tuple:
       - Ident: a
         span: "0:1-2"
       - Ident: b
         span: "0:4-5"
     span: "0:0-6"
-    "###);
+    "#);
     assert_ne!(ab, a_comma_b);
 
-    assert_yaml_snapshot!(parse_expr(r#"{amount, +amount, -amount}"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"{amount, +amount, -amount}"#).unwrap(), @r#"
     Tuple:
       - Ident: amount
         span: "0:1-7"
@@ -615,10 +579,9 @@ fn test_tuple() {
             span: "0:19-25"
         span: "0:18-25"
     span: "0:0-26"
-    "###);
+    "#);
     // Operators in tuple items
-    assert_yaml_snapshot!(parse_expr(r#"{amount, +amount, -amount}"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"{amount, +amount, -amount}"#).unwrap(), @r#"
     Tuple:
       - Ident: amount
         span: "0:1-7"
@@ -635,37 +598,32 @@ fn test_tuple() {
             span: "0:19-25"
         span: "0:18-25"
     span: "0:0-26"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_number() {
-    assert_yaml_snapshot!(parse_expr(r#"23"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"23"#).unwrap(), @r#"
     Literal:
       Integer: 23
     span: "0:0-2"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"2_3_4.5_6"#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"2_3_4.5_6"#).unwrap(), @r#"
     Literal:
       Float: 234.56
     span: "0:0-9"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"23.6"#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"23.6"#).unwrap(), @r#"
     Literal:
       Float: 23.6
     span: "0:0-4"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"23.0"#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"23.0"#).unwrap(), @r#"
     Literal:
       Float: 23
     span: "0:0-4"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"2 + 2"#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"2 + 2"#).unwrap(), @r#"
     Binary:
       left:
         Literal:
@@ -677,7 +635,7 @@ fn test_number() {
           Integer: 2
         span: "0:4-5"
     span: "0:0-5"
-    "###);
+    "#);
 
     // Underscores at the beginning are parsed as ident
     assert!(parse_expr("_2").unwrap().kind.into_ident().is_ok());
@@ -685,12 +643,11 @@ fn test_number() {
 
     assert!(parse_expr("_2.3").unwrap().kind.is_indirection());
 
-    assert_yaml_snapshot!(parse_expr(r#"2e3"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"2e3"#).unwrap(), @r#"
     Literal:
       Float: 2000
     span: "0:0-3"
-    "###);
+    "#);
 
     // expr_of_string("2_").unwrap_err(); // TODO
     // expr_of_string("2.3_").unwrap_err(); // TODO
@@ -700,8 +657,7 @@ fn test_number() {
 fn test_derive() {
     assert_yaml_snapshot!(
             parse_expr(r#"derive {x = 5, y = (-x)}"#).unwrap()
-        , @r###"
-    ---
+        , @r#"
     FuncCall:
       name:
         Ident: derive
@@ -721,15 +677,14 @@ fn test_derive() {
               alias: y
           span: "0:7-24"
     span: "0:0-24"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_select() {
     assert_yaml_snapshot!(
             parse_expr(r#"select x"#).unwrap()
-        , @r###"
-    ---
+        , @r#"
     FuncCall:
       name:
         Ident: select
@@ -738,12 +693,11 @@ fn test_select() {
         - Ident: x
           span: "0:7-8"
     span: "0:0-8"
-    "###);
+    "#);
 
     assert_yaml_snapshot!(
             parse_expr(r#"select !{x}"#).unwrap()
-        , @r###"
-    ---
+        , @r#"
     FuncCall:
       name:
         Ident: select
@@ -758,12 +712,11 @@ fn test_select() {
               span: "0:8-11"
           span: "0:7-11"
     span: "0:0-11"
-    "###);
+    "#);
 
     assert_yaml_snapshot!(
             parse_expr(r#"select {x, y}"#).unwrap()
-        , @r###"
-    ---
+        , @r#"
     FuncCall:
       name:
         Ident: select
@@ -776,15 +729,14 @@ fn test_select() {
               span: "0:11-12"
           span: "0:7-13"
     span: "0:0-13"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_expr() {
     assert_yaml_snapshot!(
             parse_expr(r#"country == "USA""#).unwrap()
-        , @r###"
-    ---
+        , @r#"
     Binary:
       left:
         Ident: country
@@ -795,13 +747,12 @@ fn test_expr() {
           String: USA
         span: "0:11-16"
     span: "0:0-16"
-    "###);
+    "#);
     assert_yaml_snapshot!(parse_expr(
                 r#"{
   gross_salary = salary + payroll_tax,
   gross_cost   = gross_salary + benefits_cost,
-}"#).unwrap(), @r###"
-    ---
+}"#).unwrap(), @r#"
     Tuple:
       - Binary:
           left:
@@ -824,13 +775,12 @@ fn test_expr() {
         span: "0:58-86"
         alias: gross_cost
     span: "0:0-89"
-    "###);
+    "#);
     assert_yaml_snapshot!(
             parse_expr(
                 "(salary + payroll_tax) * (1 + tax_rate)"
             ).unwrap(),
-            @r###"
-    ---
+            @r#"
     Binary:
       left:
         Binary:
@@ -855,7 +805,7 @@ fn test_expr() {
             span: "0:30-38"
         span: "0:26-38"
     span: "0:0-39"
-    "###);
+    "#);
 }
 
 #[test]
@@ -864,8 +814,7 @@ fn test_regex() {
             parse_expr(
                 "'oba' ~= 'foobar'"
             ).unwrap(),
-            @r###"
-    ---
+            @r#"
     Binary:
       left:
         Literal:
@@ -877,7 +826,7 @@ fn test_regex() {
           String: foobar
         span: "0:9-17"
     span: "0:0-17"
-    "###);
+    "#);
 }
 
 #[test]
@@ -886,15 +835,11 @@ fn test_func_call() {
     let ast = parse_expr(r#"count"#).unwrap();
     let ident = ast.kind.into_ident().unwrap();
     assert_yaml_snapshot!(
-            ident, @r###"
-    ---
-    count
-    "###);
+            ident, @"count");
 
     let ast = parse_expr(r#"s 'foo'"#).unwrap();
     assert_yaml_snapshot!(
-            ast, @r###"
-    ---
+            ast, @r#"
     FuncCall:
       name:
         Ident: s
@@ -904,14 +849,13 @@ fn test_func_call() {
             String: foo
           span: "0:2-7"
     span: "0:0-7"
-    "###);
+    "#);
 
     // A non-friendly option for #154
     let ast = parse_expr(r#"count s'*'"#).unwrap();
     let func_call: FuncCall = ast.kind.into_func_call().unwrap();
     assert_yaml_snapshot!(
-            func_call, @r###"
-    ---
+            func_call, @r#"
     name:
       Ident: count
       span: "0:0-5"
@@ -919,14 +863,13 @@ fn test_func_call() {
       - SString:
           - String: "*"
         span: "0:6-10"
-    "###);
+    "#);
 
     parse_expr("plus_one x:0 x:0 ").unwrap_err();
 
     let ast = parse_expr(r#"add bar to=3"#).unwrap();
     assert_yaml_snapshot!(
-            ast, @r###"
-    ---
+            ast, @r#"
     FuncCall:
       name:
         Ident: add
@@ -939,13 +882,12 @@ fn test_func_call() {
           span: "0:11-12"
           alias: to
     span: "0:0-12"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_right_assoc() {
-    assert_yaml_snapshot!(parse_expr(r#"2 ** 3 ** 4"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"2 ** 3 ** 4"#).unwrap(), @r#"
     Binary:
       left:
         Literal:
@@ -965,9 +907,8 @@ fn test_right_assoc() {
             span: "0:10-11"
         span: "0:5-11"
     span: "0:0-11"
-    "###);
-    assert_yaml_snapshot!(parse_expr(r#"1 + 2 ** (3 + 4) ** 4"#).unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr(r#"1 + 2 ** (3 + 4) ** 4"#).unwrap(), @r#"
     Binary:
       left:
         Literal:
@@ -1003,13 +944,12 @@ fn test_right_assoc() {
             span: "0:9-21"
         span: "0:4-21"
     span: "0:0-21"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_op_precedence() {
-    assert_yaml_snapshot!(parse_expr(r#"1 + 2 - 3 - 4"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"1 + 2 - 3 - 4"#).unwrap(), @r#"
     Binary:
       left:
         Binary:
@@ -1037,10 +977,9 @@ fn test_op_precedence() {
           Integer: 4
         span: "0:12-13"
     span: "0:0-13"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"1 / (3 * 4)"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"1 / (3 * 4)"#).unwrap(), @r#"
     Binary:
       left:
         Literal:
@@ -1060,10 +999,9 @@ fn test_op_precedence() {
             span: "0:9-10"
         span: "0:5-10"
     span: "0:0-11"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"1 / 2 - 3 * 4 + 1"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"1 / 2 - 3 * 4 + 1"#).unwrap(), @r#"
     Binary:
       left:
         Binary:
@@ -1099,10 +1037,9 @@ fn test_op_precedence() {
           Integer: 1
         span: "0:16-17"
     span: "0:0-17"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"a && b || !c && d"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"a && b || !c && d"#).unwrap(), @r#"
     Binary:
       left:
         Binary:
@@ -1130,10 +1067,9 @@ fn test_op_precedence() {
             span: "0:16-17"
         span: "0:10-17"
     span: "0:0-17"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"a && b + c || (d e) && f"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"a && b + c || (d e) && f"#).unwrap(), @r#"
     Binary:
       left:
         Binary:
@@ -1170,13 +1106,12 @@ fn test_op_precedence() {
             span: "0:23-24"
         span: "0:14-24"
     span: "0:0-24"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_inline_pipeline() {
-    assert_yaml_snapshot!(parse_expr("(salary | percentile 50)").unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr("(salary | percentile 50)").unwrap(), @r#"
     Pipeline:
       exprs:
         - Ident: salary
@@ -1191,29 +1126,26 @@ fn test_inline_pipeline() {
                 span: "0:21-23"
           span: "0:10-23"
     span: "0:0-24"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_dates() {
-    assert_yaml_snapshot!(parse_expr("@2011-02-01").unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr("@2011-02-01").unwrap(), @r#"
     Literal:
       Date: 2011-02-01
     span: "0:0-11"
-    "###);
-    assert_yaml_snapshot!(parse_expr("@2011-02-01T10:00").unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr("@2011-02-01T10:00").unwrap(), @r#"
     Literal:
       Timestamp: "2011-02-01T10:00"
     span: "0:0-17"
-    "###);
-    assert_yaml_snapshot!(parse_expr("@14:00").unwrap(), @r###"
-    ---
+    "#);
+    assert_yaml_snapshot!(parse_expr("@14:00").unwrap(), @r#"
     Literal:
       Time: "14:00"
     span: "0:0-6"
-    "###);
+    "#);
     // assert_yaml_snapshot!(parse_expr("@2011-02-01T10:00<datetime>").unwrap(), @"");
 
     parse_expr("@2020-01-0").unwrap_err();
@@ -1225,8 +1157,7 @@ fn test_dates() {
 
 #[test]
 fn test_ident_with_keywords() {
-    assert_yaml_snapshot!(parse_expr(r"select {andrew, orion, lettuce, falsehood, null0}").unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r"select {andrew, orion, lettuce, falsehood, null0}").unwrap(), @r#"
     FuncCall:
       name:
         Ident: select
@@ -1245,16 +1176,15 @@ fn test_ident_with_keywords() {
               span: "0:43-48"
           span: "0:7-49"
     span: "0:0-49"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r"{false}").unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r"{false}").unwrap(), @r#"
     Tuple:
       - Literal:
           Boolean: false
         span: "0:1-6"
     span: "0:0-7"
-    "###);
+    "#);
 }
 
 #[test]
@@ -1264,8 +1194,7 @@ fn test_case() {
             nickname != null => nickname,
             true => null
         ]
-        "#).unwrap(), @r###"
-    ---
+        "#).unwrap(), @r#"
     Case:
       - condition:
           Binary:
@@ -1288,30 +1217,27 @@ fn test_case() {
           Literal: "Null"
           span: "0:78-82"
     span: "0:9-92"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_params() {
-    assert_yaml_snapshot!(parse_expr(r#"$2"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"$2"#).unwrap(), @r#"
     Param: "2"
     span: "0:0-2"
-    "###);
+    "#);
 
-    assert_yaml_snapshot!(parse_expr(r#"$2_any_text"#).unwrap(), @r###"
-    ---
+    assert_yaml_snapshot!(parse_expr(r#"$2_any_text"#).unwrap(), @r#"
     Param: 2_any_text
     span: "0:0-11"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_lookup_01() {
     assert_yaml_snapshot!(parse_expr(
     r#"{a = {x = 2}}.a.x"#,
-    ).unwrap(), @r###"
-    ---
+    ).unwrap(), @r#"
     Indirection:
       base:
         Indirection:
@@ -1331,20 +1257,19 @@ fn test_lookup_01() {
       field:
         Name: x
     span: "0:0-17"
-    "###);
+    "#);
 }
 
 #[test]
 fn test_lookup_02() {
     assert_yaml_snapshot!(parse_expr(
     r#"hello.*"#,
-    ).unwrap(), @r###"
-    ---
+    ).unwrap(), @r#"
     Indirection:
       base:
         Ident: hello
         span: "0:0-5"
       field: Star
     span: "0:0-7"
-    "###);
+    "#);
 }
