@@ -26,12 +26,25 @@ impl NotAvailableValue for i32 {
     }
 }
 
-use once_cell::sync::Lazy;
+#[cfg(feature = "complex")]
+impl NotAvailableValue for num_complex::Complex64 {
+    fn is_na(&self) -> bool {
+        unsafe { self.re == savvy_ffi::R_NaReal }
+    }
 
-pub(crate) static NA_CHAR_PTR: Lazy<&str> = Lazy::new(|| unsafe {
-    let c_ptr = savvy_ffi::R_CHAR(savvy_ffi::R_NaString) as _;
-    std::str::from_utf8_unchecked(std::slice::from_raw_parts(c_ptr, 2))
-});
+    fn na() -> Self {
+        unsafe {
+            num_complex::Complex64 {
+                re: savvy_ffi::R_NaReal,
+                im: savvy_ffi::R_NaReal,
+            }
+        }
+    }
+}
+
+use once_cell::sync::OnceCell;
+
+pub(crate) static NA_CHAR_PTR: OnceCell<&str> = OnceCell::new();
 
 impl NotAvailableValue for &str {
     fn is_na(&self) -> bool {
@@ -44,6 +57,9 @@ impl NotAvailableValue for &str {
     //
     // cf., https://github.com/extendr/extendr/issues/483#issuecomment-1435499525
     fn na() -> Self {
-        NA_CHAR_PTR.as_ref()
+        NA_CHAR_PTR.get_or_init(|| unsafe {
+            let c_ptr = savvy_ffi::R_CHAR(savvy_ffi::R_NaString) as _;
+            std::str::from_utf8_unchecked(std::slice::from_raw_parts(c_ptr, 2))
+        })
     }
 }
