@@ -1,20 +1,32 @@
 use once_cell::sync::OnceCell;
 
-use crate::{IntegerSexp, NotAvailableValue, RealSexp, Sexp};
+use crate::{savvy_err, IntegerSexp, NotAvailableValue, RealSexp, Sexp};
 
 // --- Utils -------------------------
 
 const I32MAX: f64 = i32::MAX as f64;
 const I32MIN: f64 = i32::MIN as f64;
+
+// f64 can represent 2^53
+//
+// cf. https://en.wikipedia.org/wiki/Double-precision_floating-point_format,
+//     https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER
+#[cfg(target_pointer_width = "64")]
+const F64_MAX_CASTABLE_TO_USIZE: f64 = (2_u64.pow(53) - 1) as f64;
+
+// On 32-bit target, usize::MAX is less than 2^53
+#[cfg(target_pointer_width = "32")]
+const F64_MAX_CASTABLE_TO_USIZE: f64 = usize::MAX as f64;
+
 const TOLERANCE: f64 = 0.01; // This is super-tolerant than vctrs, but this should be sufficient.
 
 fn try_cast_f64_to_i32(f: f64) -> crate::Result<i32> {
     if f.is_na() || f.is_nan() {
         Ok(i32::na())
     } else if f.is_infinite() || !(I32MIN..=I32MAX).contains(&f) {
-        Err(format!("{f:?} is out of range for integer").into())
+        Err(savvy_err!("{f:?} is out of range for integer"))
     } else if (f - f.round()).abs() > TOLERANCE {
-        Err(format!("{f:?} is not integer-ish").into())
+        Err(savvy_err!("{f:?} is not integer-ish"))
     } else {
         Ok(f as i32)
     }
@@ -28,6 +40,28 @@ fn cast_i32_to_f64(i: i32) -> f64 {
     }
 }
 
+fn try_cast_i32_to_usize(i: i32) -> crate::error::Result<usize> {
+    if i.is_na() {
+        Err(savvy_err!("cannot convert NA to usize"))
+    } else {
+        Ok(<usize>::try_from(i)?)
+    }
+}
+
+fn try_cast_f64_to_usize(f: f64) -> crate::Result<usize> {
+    if f.is_na() || f.is_nan() {
+        Err(savvy_err!("cannot convert NA or NaN to usize"))
+    } else if f.is_infinite() || !(0f64..=F64_MAX_CASTABLE_TO_USIZE).contains(&f) {
+        Err(savvy_err!(
+            "{f:?} is out of range that can be safely converted to usize"
+        ))
+    } else if (f - f.round()).abs() > TOLERANCE {
+        Err(savvy_err!("{f:?} is not integer-ish"))
+    } else {
+        Ok(f as usize)
+    }
+}
+
 // --- Vector -------------------------
 
 /// A enum to hold both the original data and the converted version. Since it
@@ -280,10 +314,19 @@ impl NumericSexp {
         }
     }
 
+    /// Returns an iterator over the underlying data of the SEXP.
+    pub fn iter_usize(&self) -> NumericIteratorUsize {
+        NumericIteratorUsize {
+            sexp: self,
+            i: 0,
+            len: self.len(),
+        }
+    }
+
     // Note: If the conversion is needed, to_vec_*() would copy the values twice
     // because it creates a `Vec` from to_slice(). This is inefficient, but I'm
-    // not sure which is worse to alwaays creates a `Vec` from scratch or use
-    // the cached one. So, I chose not to implement the method.
+    // not sure which is worse to always creates a `Vec` from scratch or use the
+    // cached one. So, I chose not to implement the method.
 }
 
 impl TryFrom<Sexp> for NumericSexp {
@@ -336,7 +379,7 @@ impl TryFrom<RealSexp> for NumericSexp {
 
 // --- Iterator -----------------------
 
-/// An iterator that retuns `i32` wrapped with `Result`.
+/// An iterator that returns `i32` wrapped with `Result`.
 ///
 /// - If the underlying data is integer, use the value as it is.
 /// - If the underlying data is real, but there's already the `i32` values
@@ -349,7 +392,7 @@ pub struct NumericIteratorI32<'a> {
     len: usize,
 }
 
-impl<'a> Iterator for NumericIteratorI32<'a> {
+impl Iterator for NumericIteratorI32<'_> {
     type Item = crate::error::Result<i32>;
 
     fn next(&mut self) -> Option<Self::Item> {
@@ -373,7 +416,7 @@ impl<'a> Iterator for NumericIteratorI32<'a> {
     }
 }
 
-/// An iterator that retuns `f64`.
+/// An iterator that returns `f64`.
 ///
 /// - If the underlying data is real, use the value as it is.
 /// - If the underlying data is integer, but there's already the `f64` values
@@ -386,7 +429,7 @@ pub struct NumericIteratorF64<'a> {
     len: usize,
 }
 
-impl<'a> Iterator for NumericIteratorF64<'a> {
+impl Iterator for NumericIteratorF64<'_> {
     type Item = f64;
 
     fn next(&mut self) -> Option<Self::Item> {
@@ -410,6 +453,33 @@ impl<'a> Iterator for NumericIteratorF64<'a> {
     }
 }
 
+/// An iterator that returns `usize` wrapped with `Result`.
+pub struct NumericIteratorUsize<'a> {
+    sexp: &'a NumericSexp,
+    i: usize,
+    len: usize,
+}
+
+impl Iterator for NumericIteratorUsize<'_> {
+    type Item = crate::error::Result<usize>;
+
+    fn next(&mut self) -> Option<Self::Item> {
+        let i = self.i;
+        self.i += 1;
+
+        if i >= self.len {
+            return None;
+        }
+
+        let elem = match &self.sexp.0 {
+            PrivateNumericSexp::Integer { orig, .. } => try_cast_i32_to_usize(orig.as_slice()[i]),
+            PrivateNumericSexp::Real { orig, .. } => try_cast_f64_to_usize(orig.as_slice()[i]),
+        };
+
+        Some(elem)
+    }
+}
+
 // --- Scalar -------------------------
 
 /// A struct that holds either an integer or a real scalar.
@@ -442,6 +512,13 @@ impl NumericScalar {
             NumericScalar::Real(r) => *r,
         }
     }
+
+    pub fn as_usize(&self) -> crate::error::Result<usize> {
+        match &self {
+            NumericScalar::Integer(i) => try_cast_i32_to_usize(*i),
+            NumericScalar::Real(r) => try_cast_f64_to_usize(*r),
+        }
+    }
 }
 
 impl TryFrom<Sexp> for NumericScalar {
