@@ -17,7 +17,7 @@ use crate::ir::generic::{ColumnSort, SortDirection, WindowFrame, WindowKind};
 use crate::ir::pl::{self, Ident, Literal};
 use crate::ir::rq;
 use crate::sql::pq::context::ColumnDecl;
-use crate::utils::{OrMap, VALID_IDENT};
+use crate::utils::{valid_ident, OrMap};
 use crate::{Error, Reason, Result, Span, WithErrorInfo};
 
 pub(super) fn translate_expr(expr: rq::Expr, ctx: &mut Context) -> Result<ExprOrSource> {
@@ -380,7 +380,9 @@ fn operator_from_name(name: &str) -> Option<BinaryOperator> {
 pub(super) fn translate_literal(l: Literal, ctx: &Context) -> Result<sql_ast::Expr> {
     Ok(match l {
         Literal::Null => sql_ast::Expr::Value(Value::Null),
-        Literal::String(s) => sql_ast::Expr::Value(Value::SingleQuotedString(s)),
+        Literal::String(s) | Literal::RawString(s) => {
+            sql_ast::Expr::Value(Value::SingleQuotedString(s))
+        }
         Literal::Boolean(b) => sql_ast::Expr::Value(Value::Boolean(b)),
         Literal::Float(f) => sql_ast::Expr::Value(Value::Number(format!("{f:?}"), false)),
         Literal::Integer(i) => sql_ast::Expr::Value(Value::Number(format!("{i}"), false)),
@@ -781,6 +783,7 @@ pub(super) fn translate_column_sort(
             Some(false)
         },
         nulls_first: None,
+        with_fill: None,
     })
 }
 
@@ -810,7 +813,7 @@ pub(super) fn translate_ident(
 }
 
 pub(super) fn translate_ident_part(ident: String, ctx: &Context) -> sql_ast::Ident {
-    let is_bare = VALID_IDENT.is_match(&ident);
+    let is_bare = valid_ident().is_match(&ident);
 
     if is_bare && !keywords::is_keyword(&ident) {
         sql_ast::Ident::new(ident)
@@ -1072,66 +1075,56 @@ mod test {
 
         assert!(range_of_ranges(vec![range_1_10.clone()])?.end.is_some());
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_1_10.clone()])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_1_10.clone()])?, @r"
         start: 1
         end: 10
-        "###);
+        ");
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_1_10.clone(), range_1_10.clone()])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_1_10.clone(), range_1_10.clone()])?, @r"
         start: 1
         end: 10
-        "###);
+        ");
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_1_10.clone(), range_5_6.clone()])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_1_10.clone(), range_5_6.clone()])?, @r"
         start: 5
         end: 6
-        "###);
+        ");
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_5_6.clone(), range_1_10.clone()])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_5_6.clone(), range_1_10.clone()])?, @r"
         start: 5
         end: 6
-        "###);
+        ");
 
         // empty range
-        assert_yaml_snapshot!(range_of_ranges(vec![range_5_6.clone(), range_5_6.clone()])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_5_6.clone(), range_5_6.clone()])?, @r"
         start: ~
         end: 0
-        "###);
+        ");
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_5_inf.clone(), range_5_inf.clone()])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_5_inf.clone(), range_5_inf.clone()])?, @r"
         start: 9
         end: ~
-        "###);
+        ");
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_1_10, range_5_inf])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_1_10, range_5_inf])?, @r"
         start: 5
         end: 10
-        "###);
+        ");
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_5_6, range_inf_8.clone()])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_5_6, range_inf_8.clone()])?, @r"
         start: 5
         end: 6
-        "###);
+        ");
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_inf_8.clone(), range_inf_8])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_inf_8.clone(), range_inf_8])?, @r"
         start: ~
         end: 8
-        "###);
+        ");
 
-        assert_yaml_snapshot!(range_of_ranges(vec![range_5_5])?, @r###"
-        ---
+        assert_yaml_snapshot!(range_of_ranges(vec![range_5_5])?, @r"
         start: 5
         end: 5
-        "###);
+        ");
 
         Ok(())
     }
