@@ -1,32 +1,35 @@
 use std::collections::HashMap;
 use std::iter::zip;
 use std::path::PathBuf;
+use std::sync::OnceLock;
 
 use itertools::Itertools;
-use once_cell::sync::Lazy;
 
 use super::gen_expr::{translate_operand, ExprOrSource, SourceExpr};
 use super::{Context, Dialect};
 use crate::ir::{decl, pl, rq};
-use crate::semantic;
 use crate::utils::Pluck;
 use crate::Result;
+use crate::{debug, semantic};
 use crate::{Error, WithErrorInfo};
 
-static STD: Lazy<decl::Module> = Lazy::new(load_std_sql);
+fn std() -> &'static decl::Module {
+    static STD: OnceLock<decl::Module> = OnceLock::new();
+    STD.get_or_init(|| {
+        let _suppressed = debug::log_suppress();
 
-fn load_std_sql() -> decl::Module {
-    let std_lib = crate::SourceTree::new(
-        [(
-            PathBuf::from("std.prql"),
-            include_str!("./std.sql.prql").to_string(),
-        )],
-        None,
-    );
-    let ast = crate::parser::parse(&std_lib).unwrap();
-    let context = semantic::resolve(ast).unwrap();
+        let std_lib = crate::SourceTree::new(
+            [(
+                PathBuf::from("std.prql"),
+                include_str!("./std.sql.prql").to_string(),
+            )],
+            None,
+        );
+        let ast = crate::parser::parse(&std_lib).unwrap();
+        let context = semantic::resolve(ast).unwrap();
 
-    context.module
+        context.module
+    })
 }
 
 pub(super) fn translate_operator_expr(expr: rq::Expr, ctx: &mut Context) -> Result<ExprOrSource> {
@@ -129,7 +132,7 @@ fn find_operator_impl(
             .collect::<Vec<_>>(),
     );
 
-    let dialect_module = STD.get(&pl::Ident::from_name(dialect.to_string()));
+    let dialect_module = std().get(&pl::Ident::from_name(dialect.to_string()));
 
     let mut func_def = None;
 
@@ -139,7 +142,7 @@ fn find_operator_impl(
     }
 
     if func_def.is_none() {
-        func_def = STD.get(&operator_ident);
+        func_def = std().get(&operator_ident);
     }
 
     let decl = func_def?;
