@@ -26,8 +26,7 @@ fn basic_01() {
     {
         a = 1, "hello", [1.1, 0.0, 2.4], {null, false}
     }
-    "#), @r###"
-    ---
+    "#), @r#"
     kind:
       Tuple:
         - kind:
@@ -64,5 +63,5 @@ fn basic_01() {
                 span: "1:55-60"
           span: "1:48-61"
     span: "1:5-67"
-    "###)
+    "#)
 }
